@@ -8,8 +8,7 @@ from twisted.internet import reactor
 
 
 def run_spider(spider: Spider, pipeline: str = None,
-               settings: dict = None, override: bool = False,
-               project_name: str = 'scraping') -> None:
+               settings: dict = None, override: bool = False) -> None:
     """
     Process for running spiders.
     
@@ -31,11 +30,11 @@ def run_spider(spider: Spider, pipeline: str = None,
     
     if pipeline == 'blob':
         scrapy_settings.update({
-            'ITEM_PIPELINES': {f'{project_name}.{project_name}.pipelines.AzureBlobUploadPipeline': 1}
+            'ITEM_PIPELINES': {f'themispy.scrapy.pipelines.AzureBlobUploadPipeline': 1}
         })
     elif pipeline == 'download':
         scrapy_settings.update({
-            'ITEM_PIPELINES': {f'{project_name}.{project_name}.pipelines.AzureFileDownloaderPipeline': 1},
+            'ITEM_PIPELINES': {f'themispy.scrapy.pipelines.AzureFileDownloaderPipeline': 1},
             'FILES_STORE': 'Khipo-Themis_Project',
             'FILES_EXPIRES': 0
         })
@@ -46,7 +45,7 @@ def run_spider(spider: Spider, pipeline: str = None,
         
         scrapy_settings.update(settings)
         
-    print(f"FINAL SCRAPY SETTINGS:\n{scrapy_settings.copy_to_dict()}")
+    print(f"[FINAL SCRAPY SETTINGS]\n{scrapy_settings.copy_to_dict()}")
     
     
     def multiprocess(queue: Queue) -> None:
